@@ -1,12 +1,12 @@
 github_prefix <- "ocpu_github"
 
-getlocaldir <- function(){
+getlocaldir <- function(which = 'data'){
   if(is_rapache() || is_admin()){
     return("/usr/local/lib/opencpu")
-  } else if(getRversion() < 4 || is_windows() || is_mac()){
+  } else if(getRversion() < 4){
     rappdirs::user_data_dir('opencpu')
   } else {
-    tools::R_user_dir('opencpu')
+    tools::R_user_dir('opencpu', which)
   }
 }
 
